=======
ar_file
=======
-------------------------
Unix archive file handler
-------------------------

ar_file is a Python package to create, read, write and append to `AR archive
files`_

It is inspired by the tarfile_ and zipfile_ modules, which are part of Python's
standard library.

.. _AR archive files: https://en.wikipedia.org/wiki/Ar_(Unix)
.. _tarfile: https://docs.python.org/3/library/tarfile.html
.. _zipfile: https://docs.python.org/3/library/zipfile.html

ar_file is capable of reading the System V/GNU format only. Future releases
will add support for BSD and Solaris 64-bit formats.
